==> aws-android-sdk-cognitoidentityprovider-2.2.16-sources.jar: com/amazonaws/services/cognitoidentityprovider/model/UserPoolMfaType.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.cognitoidentityprovider.model;

/**
 * User Pool Mfa Type
 */
public enum UserPoolMfaType {
    
    OFF("OFF"),
    ON("ON"),
    OPTIONAL("OPTIONAL");

    private String value;

    private UserPoolMfaType(String value) {
        this.value = value;
    }

    @Override
    public String toString() {
        return this.value;
    }

    /**
     * Use this in place of valueOf.
     *
     * @param value
     *            real value
     * @return UserPoolMfaType corresponding to the value
     */
    public static UserPoolMfaType fromValue(String value) {
        if (value == null || "".equals(value)) {
            throw new IllegalArgumentException("Value cannot be null or empty!");
        
        } else if ("OFF".equals(value)) {
            return UserPoolMfaType.OFF;
        } else if ("ON".equals(value)) {
            return UserPoolMfaType.ON;
        } else if ("OPTIONAL".equals(value)) {
            return UserPoolMfaType.OPTIONAL;
        } else {
            throw new IllegalArgumentException("Cannot create enum from " + value + " value!");
        }
    }
}

==> aws-android-sdk-cognitoidentityprovider-2.8.2-sources.jar: com/amazonaws/services/cognitoidentityprovider/model/UserPoolMfaType.java <==
/*
 * Copyright 2010-2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cognitoidentityprovider.model;

import java.util.HashMap;
import java.util.Map;

/**
 * User Pool Mfa Type
 */
public enum UserPoolMfaType {

    OFF("OFF"),
    ON("ON"),
    OPTIONAL("OPTIONAL");

    private String value;

    private UserPoolMfaType(String value) {
        this.value = value;
    }

    @Override
    public String toString() {
        return value;
    }

    private static final Map<String, UserPoolMfaType> enumMap;
    static {
        enumMap = new HashMap<String, UserPoolMfaType>();
        enumMap.put("OFF", OFF);
        enumMap.put("ON", ON);
        enumMap.put("OPTIONAL", OPTIONAL);
    }

    /**
     * Use this in place of valueOf.
     *
     * @param value real value
     * @return UserPoolMfaType corresponding to the value
     */
    public static UserPoolMfaType fromValue(String value) {
        if (value == null || value.isEmpty()) {
            throw new IllegalArgumentException("Value cannot be null or empty!");
        } else if (enumMap.containsKey(value)) {
            return enumMap.get(value);
        } else {
            throw new IllegalArgumentException("Cannot create enum from " + value + " value!");
        }
    }
}
